window.Gleam.initSearch([{"doc":"nimiq_gleam","title":"nimiq_gleam","content":"# Nimiq for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/nimiq_gleam)](https://hex.pm/packages/nimiq_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/nimiq_gleam/)\n\nVarious modules and helpers for working with Nimiq primitives in the Gleam programming language or as a CLI.\n\n## Installation\n\n```sh\ngleam add nimiq_gleam\n```\n\n## Address module\n\n```gleam\nimport nimiq_gleam/account/address\n\npub fn main() {\n  let formatted_addr =\n    address.from_hex(&quot;0000000000000000000000000000000000000000&quot;)\n    |&gt; address.to_user_friendly_address()\n  // = &quot;NQ07 0000 0000 0000 0000 0000 0000 0000 0000&quot;\n}\n```\n\n## Key modules\n\n```gleam\nimport nimiq_gleam/account/address\nimport nimiq_gleam/key/ed25519/private_key as private_key\nimport nimiq_gleam/key/ed25519/public_key as ed25519_public_key\nimport nimiq_gleam/key/public_key\n\n// Generate a new private key\nlet private = private_key.generate()\n// Print the private key in hex format\nio.println(private_key.to_hex(private))\n// Derive its public key\nlet public = ed25519_public_key.derive_key(private)\n// Compute its address\nlet address = public_key.to_address(public)\n// Print the address in user-friendly format\nio.println(address.to_user_friendly_address(address))\n```\n\n## Transaction modules\n\n```gleam\nimport gleam/option.{None}\nimport nimiq_gleam/account/address\nimport nimiq_gleam/coin.{Coin}\nimport nimiq_gleam/key/ed25519/private_key as private_key\nimport nimiq_gleam/key/ed25519/public_key as ed25519_public_key\nimport nimiq_gleam/key/ed25519/signature as ed25519_signature\nimport nimiq_gleam/key/public_key.{EdDsaPublicKey}\nimport nimiq_gleam/key/signature.{EdDsaSignature}\nimport nimiq_gleam/transaction/enums.{TestAlbatrossNetwork}\nimport nimiq_gleam/transaction/signature_proof\nimport nimiq_gleam/transaction/transaction\n\nlet assert Ok(sender) =\n  &quot;NQ17 D2ES UBTP N14D RG4E 2KBK 217A 2GH2 NNY1&quot;\n  |&gt; address.from_user_friendly_address()\n\nlet assert Ok(recipient) =\n  &quot;NQ34 248H 248H 248H 248H 248H 248H 248H 248H&quot;\n  |&gt; address.from_user_friendly_address()\n\nlet tx =\n  transaction.new_basic(\n    sender,\n    recipient,\n    Coin(100_000_000), // Value in luna\n    Coin(138), // Fee in luna\n    100_000, // Validity start height\n    TestAlbatrossNetwork, // Network ID\n    None, // Flags\n  )\n\n// Construct signature proof\nlet assert Ok(private) =\n  private_key.from_hex(\n    &quot;0000000000000000000000000000000000000000000000000000000000000000&quot;,\n  )\nlet public_key = ed25519_public_key.derive_key(private_key)\nlet signature =\n  ed25519_signature.create(\n    private_key,\n    public_key,\n    transaction.serialize_content(tx),\n  )\nlet proof = signature_proof.single_sig(\n  EdDsaPublicKey(public_key),\n  EdDsaSignature(signature),\n)\n\n// Add proof to transaction\nlet tx = transaction.set_signature_proof(tx, proof)\n\n// Print the serialized transaction as a hex string\nio.println(transaction.to_hex(tx))\n```\n\n## CLI\n\nUse `--help` at the root or command level to see usage instructions.\n\n### Address command\n\nConvert an address from any string format to another string format.\n\n```sh\n# See usage instructions:\nnimiq_gleam address --help\n\n# From hex to user-friendly:\nnimiq_gleam address 0000000000000000000000000000000000000000 --format=user-friendly\n# Output:\n# &quot;NQ07 0000 0000 0000 0000 0000 0000 0000 0000&quot;\n```\n\n### New-Tx command\n\nCreate and optionally sign transactions for Nimiq PoS.\n\n```sh\n# See usage instructions:\nnimiq_gleam new-tx --help\n\n# Create and optionally sign a transaction\nnimiq_gleam new-tx \\\n  &quot;NQ17 D2ES UBTP N14D RG4E 2KBK 217A 2GH2 NNY1&quot; \\\n  &quot;NQ34 248H 248H 248H 248H 248H 248H 248H 248H&quot; \\\n  100000000 \\\n  100000 \\\n  --fee=138 \\\n  --msg=&quot;Nimiq rocks\\!&quot; \\\n  --sign-with=0000000000000000000000000000000000000000000000000000000000000000\n# Output:\n# 01689dae2f77b048dcc08e14d73104ea14222b5be1000011111111111111111111111111111111\n# 11111111000c4e696d697120726f636b73210000000005f5e100000000000000008a000186a005\n# 0062003b6a27bcceb6a42d62a3a8d02a6f0d73653215771de243a63ac048a18b59da2900ae6c4c\n# 8bc8b3cbf2e96a1845e846bc65e5e9d60d9989746cb14e7f0b195d77ec48eaaf592dc3720ba2d0\n# 95fa7d15808c168b687cb0092e16f332f313ab45c609\n```\n\n&lt;!-- Further documentation can be found at &lt;https://hexdocs.pm/nimiq_gleam&gt;. --&gt;\n\n## Development\n\n```sh\ngleam format # Format the code\ngleam test   # Run the tests\ngleam run    # Run the cli\n```\n","url":"index.html"},{"doc":"account/account","title":"AccountType","content":"pub type AccountType {\n  BasicAccount\n  VestingContract\n  HashedTimeLockedContract\n  StakingContract\n}\n\nBasicAccount\n\n\nVestingContract\n\n\nHashedTimeLockedContract\n\n\nStakingContract\n\n\nSynonyms:\naccount/account.AccountType\naccount/account AccountType","url":"account/account.html#AccountType"},{"doc":"account/account","title":"from_account_type","content":"pub fn from_account_type(account_type: AccountType) -&gt; Int\n\nSynonyms:\naccount/account.from_account_type\naccount/account from_account_type","url":"account/account.html#from_account_type"},{"doc":"account/account","title":"to_account_type","content":"pub fn to_account_type(\n  account_type: Int,\n) -&gt; Result(AccountType, String)\n\nSynonyms:\naccount/account.to_account_type\naccount/account to_account_type","url":"account/account.html#to_account_type"},{"doc":"account/account","title":"account/account","content":"","url":"account/account.html"},{"doc":"utils/base32","title":"decode","content":"pub fn decode(\n  str: String,\n  alphabet: String,\n) -&gt; Result(BitArray, String)\n\nSynonyms:\nutils/base32.decode\nutils/base32 decode","url":"utils/base32.html#decode"},{"doc":"utils/base32","title":"encode","content":"pub fn encode(buf: BitArray, alphabet: String) -&gt; String\n\nSynonyms:\nutils/base32.encode\nutils/base32 encode","url":"utils/base32.html#encode"},{"doc":"utils/base32","title":"utils/base32","content":"","url":"utils/base32.html"},{"doc":"utils/misc","title":"to_hex","content":"pub fn to_hex(buf: BitArray) -&gt; String\n\nSynonyms:\nutils/misc.to_hex\nutils/misc to_hex","url":"utils/misc.html#to_hex"},{"doc":"utils/misc","title":"unwrap","content":"pub fn unwrap(res: Result(a, b)) -&gt; a\n For when you really know the Result cannot be Error\nSynonyms:\nutils/misc.unwrap\nutils/misc unwrap","url":"utils/misc.html#unwrap"},{"doc":"utils/misc","title":"utils/misc","content":"","url":"utils/misc.html"},{"doc":"account/address","title":"Address","content":"pub opaque type Address\n\n\nSynonyms:\naccount/address.Address\naccount/address Address","url":"account/address.html#Address"},{"doc":"account/address","title":"deserialize","content":"pub fn deserialize(\n  buf: BitArray,\n) -&gt; Result(#(Address, BitArray), String)\n\nSynonyms:\naccount/address.deserialize\naccount/address deserialize","url":"account/address.html#deserialize"},{"doc":"account/address","title":"deserialize_all","content":"pub fn deserialize_all(buf: BitArray) -&gt; Result(Address, String)\n\nSynonyms:\naccount/address.deserialize_all\naccount/address deserialize_all","url":"account/address.html#deserialize_all"},{"doc":"account/address","title":"from_base64","content":"pub fn from_base64(base64: String) -&gt; Result(Address, String)\n\nSynonyms:\naccount/address.from_base64\naccount/address from_base64","url":"account/address.html#from_base64"},{"doc":"account/address","title":"from_base64_url","content":"pub fn from_base64_url(\n  base64_url: String,\n) -&gt; Result(Address, String)\n\nSynonyms:\naccount/address.from_base64_url\naccount/address from_base64_url","url":"account/address.html#from_base64_url"},{"doc":"account/address","title":"from_hash","content":"pub fn from_hash(hash: BitArray) -&gt; Result(Address, String)\n\nSynonyms:\naccount/address.from_hash\naccount/address from_hash","url":"account/address.html#from_hash"},{"doc":"account/address","title":"from_hex","content":"pub fn from_hex(hex: String) -&gt; Result(Address, String)\n\nSynonyms:\naccount/address.from_hex\naccount/address from_hex","url":"account/address.html#from_hex"},{"doc":"account/address","title":"from_string","content":"pub fn from_string(str: String) -&gt; Result(Address, String)\n\nSynonyms:\naccount/address.from_string\naccount/address from_string","url":"account/address.html#from_string"},{"doc":"account/address","title":"from_user_friendly_address","content":"pub fn from_user_friendly_address(\n  str: String,\n) -&gt; Result(Address, String)\n\nSynonyms:\naccount/address.from_user_friendly_address\naccount/address from_user_friendly_address","url":"account/address.html#from_user_friendly_address"},{"doc":"account/address","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  address: Address,\n) -&gt; BytesBuilder\n\nSynonyms:\naccount/address.serialize\naccount/address serialize","url":"account/address.html#serialize"},{"doc":"account/address","title":"serialize_to_bits","content":"pub fn serialize_to_bits(address: Address) -&gt; BitArray\n\nSynonyms:\naccount/address.serialize_to_bits\naccount/address serialize_to_bits","url":"account/address.html#serialize_to_bits"},{"doc":"account/address","title":"to_base64","content":"pub fn to_base64(address: Address) -&gt; String\n\nSynonyms:\naccount/address.to_base64\naccount/address to_base64","url":"account/address.html#to_base64"},{"doc":"account/address","title":"to_base64_url","content":"pub fn to_base64_url(address: Address) -&gt; String\n\nSynonyms:\naccount/address.to_base64_url\naccount/address to_base64_url","url":"account/address.html#to_base64_url"},{"doc":"account/address","title":"to_hex","content":"pub fn to_hex(address: Address) -&gt; String\n\nSynonyms:\naccount/address.to_hex\naccount/address to_hex","url":"account/address.html#to_hex"},{"doc":"account/address","title":"to_user_friendly_address","content":"pub fn to_user_friendly_address(address: Address) -&gt; String\n\nSynonyms:\naccount/address.to_user_friendly_address\naccount/address to_user_friendly_address","url":"account/address.html#to_user_friendly_address"},{"doc":"account/address","title":"zero","content":"pub fn zero() -&gt; Address\n\nSynonyms:\naccount/address.zero\naccount/address zero","url":"account/address.html#zero"},{"doc":"account/address","title":"account/address","content":"","url":"account/address.html"},{"doc":"bindings/blake2","title":"hash2b","content":"pub fn hash2b(m: BitArray, output_size: Int) -&gt; BitArray\n Blake2b hashing\n\n Note that the `output_size` is in bytes, not bits\n\n - 64 =&gt; Blake2b-512 (default)\n - 48 =&gt; Blake2b-384\n - 32 =&gt; Blake2b-256\n\n Per the specification, any `output_size` between 1 and 64 bytes is supported.\nSynonyms:\nbindings/blake2.hash2b\nbindings/blake2 hash2b","url":"bindings/blake2.html#hash2b"},{"doc":"bindings/blake2","title":"bindings/blake2","content":"","url":"bindings/blake2.html"},{"doc":"bindings/ed25519","title":"Key","content":"pub type Key =\n  BitArray\n Public or secret key\n\nSynonyms:\nbindings/ed25519.Key\nbindings/ed25519 Key","url":"bindings/ed25519.html#Key"},{"doc":"bindings/ed25519","title":"Signature","content":"pub type Signature =\n  BitArray\n Computed signature\n\nSynonyms:\nbindings/ed25519.Signature\nbindings/ed25519 Signature","url":"bindings/ed25519.html#Signature"},{"doc":"bindings/ed25519","title":"derive_public_key","content":"pub fn derive_public_key(sk: BitArray) -&gt; BitArray\n Derive the public signing key from the secret key\nSynonyms:\nbindings/ed25519.derive_public_key\nbindings/ed25519 derive_public_key","url":"bindings/ed25519.html#derive_public_key"},{"doc":"bindings/ed25519","title":"generate_key_pair","content":"pub fn generate_key_pair() -&gt; #(BitArray, BitArray)\n Generate a secret/public key pair\n\n Returned tuple contains `#(random_secret_key, derived_public_key)`\nSynonyms:\nbindings/ed25519.generate_key_pair\nbindings/ed25519 generate_key_pair","url":"bindings/ed25519.html#generate_key_pair"},{"doc":"bindings/ed25519","title":"on_curve","content":"pub fn on_curve(key: BitArray) -&gt; Bool\n Returns whether a given `key` lies on the ed25519 curve.\nSynonyms:\nbindings/ed25519.on_curve\nbindings/ed25519 on_curve","url":"bindings/ed25519.html#on_curve"},{"doc":"bindings/ed25519","title":"signature","content":"pub fn signature(\n  m: BitArray,\n  sk: BitArray,\n  pk: BitArray,\n) -&gt; BitArray\n Sign a message\nSynonyms:\nbindings/ed25519.signature\nbindings/ed25519 signature","url":"bindings/ed25519.html#signature"},{"doc":"bindings/ed25519","title":"valid_signature","content":"pub fn valid_signature(\n  sig: BitArray,\n  m: BitArray,\n  pk: BitArray,\n) -&gt; Bool\n Validate a signed message\nSynonyms:\nbindings/ed25519.valid_signature\nbindings/ed25519 valid_signature","url":"bindings/ed25519.html#valid_signature"},{"doc":"bindings/ed25519","title":"bindings/ed25519","content":"","url":"bindings/ed25519.html"},{"doc":"bindings/varint","title":"decode","content":"pub fn decode(b: BitArray) -&gt; #(Int, BitArray)\n Decodes LEB128 encoded bytes to an unsigned integer.\n\n Returns a tuple where the first element is the decoded value and the second element the bytes which have not been\n parsed.\n\n This function will raise ArgumentError if the given b is not a valid LEB128 integer.\nSynonyms:\nbindings/varint.decode\nbindings/varint decode","url":"bindings/varint.html#decode"},{"doc":"bindings/varint","title":"encode","content":"pub fn encode(num: Int) -&gt; BitArray\n Encodes an unsigned integer using LEB128 compression.\nSynonyms:\nbindings/varint.encode\nbindings/varint encode","url":"bindings/varint.html#encode"},{"doc":"bindings/varint","title":"bindings/varint","content":"","url":"bindings/varint.html"},{"doc":"cli/address_command","title":"run","content":"pub fn run() -&gt; Command(Nil)\n The glint command that will be executed\nSynonyms:\ncli/address_command.run\ncli/address_command run","url":"cli/address_command.html#run"},{"doc":"cli/address_command","title":"cli/address_command","content":"","url":"cli/address_command.html"},{"doc":"coin","title":"Coin","content":"pub type Coin {\n  Coin(luna: Int)\n}\n\nCoin(luna: Int)\n\n\nSynonyms:\ncoin.Coin\ncoin Coin","url":"coin.html#Coin"},{"doc":"coin","title":"decimals","content":"pub const decimals: Int\n\nSynonyms:\ncoin.decimals\ncoin decimals","url":"coin.html#decimals"},{"doc":"coin","title":"lunas_per_coin","content":"pub const lunas_per_coin: Float\n\nSynonyms:\ncoin.lunas_per_coin\ncoin lunas_per_coin","url":"coin.html#lunas_per_coin"},{"doc":"coin","title":"coins_to_lunas","content":"pub fn coins_to_lunas(coins: Float) -&gt; Coin\n\nSynonyms:\ncoin.coins_to_lunas\ncoin coins_to_lunas","url":"coin.html#coins_to_lunas"},{"doc":"coin","title":"lunas_to_coins","content":"pub fn lunas_to_coins(lunas: Coin) -&gt; Float\n\nSynonyms:\ncoin.lunas_to_coins\ncoin lunas_to_coins","url":"coin.html#lunas_to_coins"},{"doc":"coin","title":"coin","content":"","url":"coin.html"},{"doc":"key/ed25519/private_key","title":"PrivateKey","content":"pub opaque type PrivateKey\n\n\nSynonyms:\nkey/ed25519/private_key.PrivateKey\nkey/ed25519/private_key PrivateKey","url":"key/ed25519/private_key.html#PrivateKey"},{"doc":"key/ed25519/private_key","title":"deserialize","content":"pub fn deserialize(\n  buf: BitArray,\n) -&gt; Result(#(PrivateKey, BitArray), String)\n\nSynonyms:\nkey/ed25519/private_key.deserialize\nkey/ed25519/private_key deserialize","url":"key/ed25519/private_key.html#deserialize"},{"doc":"key/ed25519/private_key","title":"deserialize_all","content":"pub fn deserialize_all(\n  buf: BitArray,\n) -&gt; Result(PrivateKey, String)\n\nSynonyms:\nkey/ed25519/private_key.deserialize_all\nkey/ed25519/private_key deserialize_all","url":"key/ed25519/private_key.html#deserialize_all"},{"doc":"key/ed25519/private_key","title":"from_base64","content":"pub fn from_base64(base64: String) -&gt; Result(PrivateKey, String)\n\nSynonyms:\nkey/ed25519/private_key.from_base64\nkey/ed25519/private_key from_base64","url":"key/ed25519/private_key.html#from_base64"},{"doc":"key/ed25519/private_key","title":"from_base64_url","content":"pub fn from_base64_url(\n  base64_url: String,\n) -&gt; Result(PrivateKey, String)\n\nSynonyms:\nkey/ed25519/private_key.from_base64_url\nkey/ed25519/private_key from_base64_url","url":"key/ed25519/private_key.html#from_base64_url"},{"doc":"key/ed25519/private_key","title":"from_hex","content":"pub fn from_hex(hex: String) -&gt; Result(PrivateKey, String)\n\nSynonyms:\nkey/ed25519/private_key.from_hex\nkey/ed25519/private_key from_hex","url":"key/ed25519/private_key.html#from_hex"},{"doc":"key/ed25519/private_key","title":"from_string","content":"pub fn from_string(str: String) -&gt; Result(PrivateKey, String)\n\nSynonyms:\nkey/ed25519/private_key.from_string\nkey/ed25519/private_key from_string","url":"key/ed25519/private_key.html#from_string"},{"doc":"key/ed25519/private_key","title":"generate","content":"pub fn generate() -&gt; PrivateKey\n\nSynonyms:\nkey/ed25519/private_key.generate\nkey/ed25519/private_key generate","url":"key/ed25519/private_key.html#generate"},{"doc":"key/ed25519/private_key","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  key: PrivateKey,\n) -&gt; BytesBuilder\n\nSynonyms:\nkey/ed25519/private_key.serialize\nkey/ed25519/private_key serialize","url":"key/ed25519/private_key.html#serialize"},{"doc":"key/ed25519/private_key","title":"serialize_to_bits","content":"pub fn serialize_to_bits(key: PrivateKey) -&gt; BitArray\n\nSynonyms:\nkey/ed25519/private_key.serialize_to_bits\nkey/ed25519/private_key serialize_to_bits","url":"key/ed25519/private_key.html#serialize_to_bits"},{"doc":"key/ed25519/private_key","title":"to_base64","content":"pub fn to_base64(key: PrivateKey) -&gt; String\n\nSynonyms:\nkey/ed25519/private_key.to_base64\nkey/ed25519/private_key to_base64","url":"key/ed25519/private_key.html#to_base64"},{"doc":"key/ed25519/private_key","title":"to_base64_url","content":"pub fn to_base64_url(key: PrivateKey) -&gt; String\n\nSynonyms:\nkey/ed25519/private_key.to_base64_url\nkey/ed25519/private_key to_base64_url","url":"key/ed25519/private_key.html#to_base64_url"},{"doc":"key/ed25519/private_key","title":"to_hex","content":"pub fn to_hex(key: PrivateKey) -&gt; String\n\nSynonyms:\nkey/ed25519/private_key.to_hex\nkey/ed25519/private_key to_hex","url":"key/ed25519/private_key.html#to_hex"},{"doc":"key/ed25519/private_key","title":"key/ed25519/private_key","content":"","url":"key/ed25519/private_key.html"},{"doc":"key/ed25519/public_key","title":"PublicKey","content":"pub opaque type PublicKey\n\n\nSynonyms:\nkey/ed25519/public_key.PublicKey\nkey/ed25519/public_key PublicKey","url":"key/ed25519/public_key.html#PublicKey"},{"doc":"key/ed25519/public_key","title":"derive_key","content":"pub fn derive_key(private: PrivateKey) -&gt; PublicKey\n\nSynonyms:\nkey/ed25519/public_key.derive_key\nkey/ed25519/public_key derive_key","url":"key/ed25519/public_key.html#derive_key"},{"doc":"key/ed25519/public_key","title":"deserialize","content":"pub fn deserialize(\n  buf: BitArray,\n) -&gt; Result(#(PublicKey, BitArray), String)\n\nSynonyms:\nkey/ed25519/public_key.deserialize\nkey/ed25519/public_key deserialize","url":"key/ed25519/public_key.html#deserialize"},{"doc":"key/ed25519/public_key","title":"deserialize_all","content":"pub fn deserialize_all(\n  buf: BitArray,\n) -&gt; Result(PublicKey, String)\n\nSynonyms:\nkey/ed25519/public_key.deserialize_all\nkey/ed25519/public_key deserialize_all","url":"key/ed25519/public_key.html#deserialize_all"},{"doc":"key/ed25519/public_key","title":"from_base64","content":"pub fn from_base64(base64: String) -&gt; Result(PublicKey, String)\n\nSynonyms:\nkey/ed25519/public_key.from_base64\nkey/ed25519/public_key from_base64","url":"key/ed25519/public_key.html#from_base64"},{"doc":"key/ed25519/public_key","title":"from_base64_url","content":"pub fn from_base64_url(\n  base64_url: String,\n) -&gt; Result(PublicKey, String)\n\nSynonyms:\nkey/ed25519/public_key.from_base64_url\nkey/ed25519/public_key from_base64_url","url":"key/ed25519/public_key.html#from_base64_url"},{"doc":"key/ed25519/public_key","title":"from_hex","content":"pub fn from_hex(hex: String) -&gt; Result(PublicKey, String)\n\nSynonyms:\nkey/ed25519/public_key.from_hex\nkey/ed25519/public_key from_hex","url":"key/ed25519/public_key.html#from_hex"},{"doc":"key/ed25519/public_key","title":"from_string","content":"pub fn from_string(str: String) -&gt; Result(PublicKey, String)\n\nSynonyms:\nkey/ed25519/public_key.from_string\nkey/ed25519/public_key from_string","url":"key/ed25519/public_key.html#from_string"},{"doc":"key/ed25519/public_key","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  key: PublicKey,\n) -&gt; BytesBuilder\n\nSynonyms:\nkey/ed25519/public_key.serialize\nkey/ed25519/public_key serialize","url":"key/ed25519/public_key.html#serialize"},{"doc":"key/ed25519/public_key","title":"serialize_to_bits","content":"pub fn serialize_to_bits(key: PublicKey) -&gt; BitArray\n\nSynonyms:\nkey/ed25519/public_key.serialize_to_bits\nkey/ed25519/public_key serialize_to_bits","url":"key/ed25519/public_key.html#serialize_to_bits"},{"doc":"key/ed25519/public_key","title":"to_base64","content":"pub fn to_base64(key: PublicKey) -&gt; String\n\nSynonyms:\nkey/ed25519/public_key.to_base64\nkey/ed25519/public_key to_base64","url":"key/ed25519/public_key.html#to_base64"},{"doc":"key/ed25519/public_key","title":"to_base64_url","content":"pub fn to_base64_url(key: PublicKey) -&gt; String\n\nSynonyms:\nkey/ed25519/public_key.to_base64_url\nkey/ed25519/public_key to_base64_url","url":"key/ed25519/public_key.html#to_base64_url"},{"doc":"key/ed25519/public_key","title":"to_hex","content":"pub fn to_hex(key: PublicKey) -&gt; String\n\nSynonyms:\nkey/ed25519/public_key.to_hex\nkey/ed25519/public_key to_hex","url":"key/ed25519/public_key.html#to_hex"},{"doc":"key/ed25519/public_key","title":"key/ed25519/public_key","content":"","url":"key/ed25519/public_key.html"},{"doc":"key/ed25519/signature","title":"Signature","content":"pub opaque type Signature\n\n\nSynonyms:\nkey/ed25519/signature.Signature\nkey/ed25519/signature Signature","url":"key/ed25519/signature.html#Signature"},{"doc":"key/ed25519/signature","title":"size","content":"pub const size: Int\n\nSynonyms:\nkey/ed25519/signature.size\nkey/ed25519/signature size","url":"key/ed25519/signature.html#size"},{"doc":"key/ed25519/signature","title":"create","content":"pub fn create(\n  private: PrivateKey,\n  public: PublicKey,\n  data: BitArray,\n) -&gt; Signature\n\nSynonyms:\nkey/ed25519/signature.create\nkey/ed25519/signature create","url":"key/ed25519/signature.html#create"},{"doc":"key/ed25519/signature","title":"deserialize","content":"pub fn deserialize(\n  buf: BitArray,\n) -&gt; Result(#(Signature, BitArray), String)\n\nSynonyms:\nkey/ed25519/signature.deserialize\nkey/ed25519/signature deserialize","url":"key/ed25519/signature.html#deserialize"},{"doc":"key/ed25519/signature","title":"deserialize_all","content":"pub fn deserialize_all(\n  buf: BitArray,\n) -&gt; Result(Signature, String)\n\nSynonyms:\nkey/ed25519/signature.deserialize_all\nkey/ed25519/signature deserialize_all","url":"key/ed25519/signature.html#deserialize_all"},{"doc":"key/ed25519/signature","title":"from_base64","content":"pub fn from_base64(base64: String) -&gt; Result(Signature, String)\n\nSynonyms:\nkey/ed25519/signature.from_base64\nkey/ed25519/signature from_base64","url":"key/ed25519/signature.html#from_base64"},{"doc":"key/ed25519/signature","title":"from_base64_url","content":"pub fn from_base64_url(\n  base64_url: String,\n) -&gt; Result(Signature, String)\n\nSynonyms:\nkey/ed25519/signature.from_base64_url\nkey/ed25519/signature from_base64_url","url":"key/ed25519/signature.html#from_base64_url"},{"doc":"key/ed25519/signature","title":"from_hex","content":"pub fn from_hex(hex: String) -&gt; Result(Signature, String)\n\nSynonyms:\nkey/ed25519/signature.from_hex\nkey/ed25519/signature from_hex","url":"key/ed25519/signature.html#from_hex"},{"doc":"key/ed25519/signature","title":"from_string","content":"pub fn from_string(str: String) -&gt; Result(Signature, String)\n\nSynonyms:\nkey/ed25519/signature.from_string\nkey/ed25519/signature from_string","url":"key/ed25519/signature.html#from_string"},{"doc":"key/ed25519/signature","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  sig: Signature,\n) -&gt; BytesBuilder\n\nSynonyms:\nkey/ed25519/signature.serialize\nkey/ed25519/signature serialize","url":"key/ed25519/signature.html#serialize"},{"doc":"key/ed25519/signature","title":"serialize_to_bits","content":"pub fn serialize_to_bits(sig: Signature) -&gt; BitArray\n\nSynonyms:\nkey/ed25519/signature.serialize_to_bits\nkey/ed25519/signature serialize_to_bits","url":"key/ed25519/signature.html#serialize_to_bits"},{"doc":"key/ed25519/signature","title":"to_base64","content":"pub fn to_base64(sig: Signature) -&gt; String\n\nSynonyms:\nkey/ed25519/signature.to_base64\nkey/ed25519/signature to_base64","url":"key/ed25519/signature.html#to_base64"},{"doc":"key/ed25519/signature","title":"to_base64_url","content":"pub fn to_base64_url(sig: Signature) -&gt; String\n\nSynonyms:\nkey/ed25519/signature.to_base64_url\nkey/ed25519/signature to_base64_url","url":"key/ed25519/signature.html#to_base64_url"},{"doc":"key/ed25519/signature","title":"to_hex","content":"pub fn to_hex(sig: Signature) -&gt; String\n\nSynonyms:\nkey/ed25519/signature.to_hex\nkey/ed25519/signature to_hex","url":"key/ed25519/signature.html#to_hex"},{"doc":"key/ed25519/signature","title":"key/ed25519/signature","content":"","url":"key/ed25519/signature.html"},{"doc":"transaction/enums","title":"NetworkId","content":"pub type NetworkId {\n  TestAlbatrossNetwork\n  MainAlbatrossNetwork\n}\n\nTestAlbatrossNetwork\n\n\nMainAlbatrossNetwork\n\n\nSynonyms:\ntransaction/enums.NetworkId\ntransaction/enums NetworkId","url":"transaction/enums.html#NetworkId"},{"doc":"transaction/enums","title":"SignatureProofAlgorithm","content":"pub type SignatureProofAlgorithm {\n  Ed25519Algorithm\n  ES256Algorithm\n}\n\nEd25519Algorithm\n\n\nES256Algorithm\n\n\nSynonyms:\ntransaction/enums.SignatureProofAlgorithm\ntransaction/enums SignatureProofAlgorithm","url":"transaction/enums.html#SignatureProofAlgorithm"},{"doc":"transaction/enums","title":"TransactionFormat","content":"pub type TransactionFormat {\n  BasicFormat\n  ExtendedFormat\n}\n\nBasicFormat\n\n\nExtendedFormat\n\n\nSynonyms:\ntransaction/enums.TransactionFormat\ntransaction/enums TransactionFormat","url":"transaction/enums.html#TransactionFormat"},{"doc":"transaction/enums","title":"from_network_id","content":"pub fn from_network_id(network_id: NetworkId) -&gt; Int\n\nSynonyms:\ntransaction/enums.from_network_id\ntransaction/enums from_network_id","url":"transaction/enums.html#from_network_id"},{"doc":"transaction/enums","title":"from_signature_algorithm","content":"pub fn from_signature_algorithm(\n  alg: SignatureProofAlgorithm,\n) -&gt; Int\n\nSynonyms:\ntransaction/enums.from_signature_algorithm\ntransaction/enums from_signature_algorithm","url":"transaction/enums.html#from_signature_algorithm"},{"doc":"transaction/enums","title":"from_transaction_format","content":"pub fn from_transaction_format(format: TransactionFormat) -&gt; Int\n\nSynonyms:\ntransaction/enums.from_transaction_format\ntransaction/enums from_transaction_format","url":"transaction/enums.html#from_transaction_format"},{"doc":"transaction/enums","title":"to_network_id","content":"pub fn to_network_id(\n  network_id: Int,\n) -&gt; Result(NetworkId, String)\n\nSynonyms:\ntransaction/enums.to_network_id\ntransaction/enums to_network_id","url":"transaction/enums.html#to_network_id"},{"doc":"transaction/enums","title":"to_signature_algorithm","content":"pub fn to_signature_algorithm(\n  alg: Int,\n) -&gt; Result(SignatureProofAlgorithm, String)\n\nSynonyms:\ntransaction/enums.to_signature_algorithm\ntransaction/enums to_signature_algorithm","url":"transaction/enums.html#to_signature_algorithm"},{"doc":"transaction/enums","title":"to_transaction_format","content":"pub fn to_transaction_format(\n  format: Int,\n) -&gt; Result(TransactionFormat, String)\n\nSynonyms:\ntransaction/enums.to_transaction_format\ntransaction/enums to_transaction_format","url":"transaction/enums.html#to_transaction_format"},{"doc":"transaction/enums","title":"transaction/enums","content":"","url":"transaction/enums.html"},{"doc":"key/public_key","title":"PublicKey","content":"pub type PublicKey {\n  EdDsaPublicKey(key: ed25519_public_key.PublicKey)\n  EcDsaPublicKey(buf: BitArray)\n}\n\nEdDsaPublicKey(key: ed25519_public_key.PublicKey)\n\n\nEcDsaPublicKey(buf: BitArray)\n\n\nSynonyms:\nkey/public_key.PublicKey\nkey/public_key PublicKey","url":"key/public_key.html#PublicKey"},{"doc":"key/public_key","title":"deserialize_typed","content":"pub fn deserialize_typed(\n  buf: BitArray,\n  typ: SignatureProofAlgorithm,\n) -&gt; Result(#(PublicKey, BitArray), String)\n\nSynonyms:\nkey/public_key.deserialize_typed\nkey/public_key deserialize_typed","url":"key/public_key.html#deserialize_typed"},{"doc":"key/public_key","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  key: PublicKey,\n) -&gt; BytesBuilder\n\nSynonyms:\nkey/public_key.serialize\nkey/public_key serialize","url":"key/public_key.html#serialize"},{"doc":"key/public_key","title":"serialize_to_bits","content":"pub fn serialize_to_bits(key: PublicKey) -&gt; BitArray\n\nSynonyms:\nkey/public_key.serialize_to_bits\nkey/public_key serialize_to_bits","url":"key/public_key.html#serialize_to_bits"},{"doc":"key/public_key","title":"to_address","content":"pub fn to_address(key: PublicKey) -&gt; Address\n\nSynonyms:\nkey/public_key.to_address\nkey/public_key to_address","url":"key/public_key.html#to_address"},{"doc":"key/public_key","title":"to_base64","content":"pub fn to_base64(key: PublicKey) -&gt; String\n\nSynonyms:\nkey/public_key.to_base64\nkey/public_key to_base64","url":"key/public_key.html#to_base64"},{"doc":"key/public_key","title":"to_base64_url","content":"pub fn to_base64_url(key: PublicKey) -&gt; String\n\nSynonyms:\nkey/public_key.to_base64_url\nkey/public_key to_base64_url","url":"key/public_key.html#to_base64_url"},{"doc":"key/public_key","title":"to_hex","content":"pub fn to_hex(key: PublicKey) -&gt; String\n\nSynonyms:\nkey/public_key.to_hex\nkey/public_key to_hex","url":"key/public_key.html#to_hex"},{"doc":"key/public_key","title":"key/public_key","content":"","url":"key/public_key.html"},{"doc":"key/signature","title":"Signature","content":"pub type Signature {\n  EdDsaSignature(sig: ed25519_signature.Signature)\n  EcDsaSignature(buf: BitArray)\n}\n\nEdDsaSignature(sig: ed25519_signature.Signature)\n\n\nEcDsaSignature(buf: BitArray)\n\n\nSynonyms:\nkey/signature.Signature\nkey/signature Signature","url":"key/signature.html#Signature"},{"doc":"key/signature","title":"create","content":"pub fn create(\n  private: PrivateKey,\n  public: PublicKey,\n  data: BitArray,\n) -&gt; Signature\n\nSynonyms:\nkey/signature.create\nkey/signature create","url":"key/signature.html#create"},{"doc":"key/signature","title":"deserialize_typed","content":"pub fn deserialize_typed(\n  buf: BitArray,\n  typ: SignatureProofAlgorithm,\n) -&gt; Result(#(Signature, BitArray), String)\n\nSynonyms:\nkey/signature.deserialize_typed\nkey/signature deserialize_typed","url":"key/signature.html#deserialize_typed"},{"doc":"key/signature","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  sig: Signature,\n) -&gt; BytesBuilder\n\nSynonyms:\nkey/signature.serialize\nkey/signature serialize","url":"key/signature.html#serialize"},{"doc":"key/signature","title":"serialize_to_bits","content":"pub fn serialize_to_bits(sig: Signature) -&gt; BitArray\n\nSynonyms:\nkey/signature.serialize_to_bits\nkey/signature serialize_to_bits","url":"key/signature.html#serialize_to_bits"},{"doc":"key/signature","title":"to_base64","content":"pub fn to_base64(sig: Signature) -&gt; String\n\nSynonyms:\nkey/signature.to_base64\nkey/signature to_base64","url":"key/signature.html#to_base64"},{"doc":"key/signature","title":"to_base64_url","content":"pub fn to_base64_url(sig: Signature) -&gt; String\n\nSynonyms:\nkey/signature.to_base64_url\nkey/signature to_base64_url","url":"key/signature.html#to_base64_url"},{"doc":"key/signature","title":"to_hex","content":"pub fn to_hex(sig: Signature) -&gt; String\n\nSynonyms:\nkey/signature.to_hex\nkey/signature to_hex","url":"key/signature.html#to_hex"},{"doc":"key/signature","title":"key/signature","content":"","url":"key/signature.html"},{"doc":"utils/serde","title":"deserialize_bool","content":"pub fn deserialize_bool(\n  buf: BitArray,\n) -&gt; Result(#(Bool, BitArray), String)\n\nSynonyms:\nutils/serde.deserialize_bool\nutils/serde deserialize_bool","url":"utils/serde.html#deserialize_bool"},{"doc":"utils/serde","title":"deserialize_bytes","content":"pub fn deserialize_bytes(\n  buf: BitArray,\n) -&gt; Result(#(BitArray, BitArray), String)\n\nSynonyms:\nutils/serde.deserialize_bytes\nutils/serde deserialize_bytes","url":"utils/serde.html#deserialize_bytes"},{"doc":"utils/serde","title":"deserialize_int","content":"pub fn deserialize_int(\n  buf: BitArray,\n  bit_size: Int,\n) -&gt; Result(#(Int, BitArray), String)\n\nSynonyms:\nutils/serde.deserialize_int\nutils/serde deserialize_int","url":"utils/serde.html#deserialize_int"},{"doc":"utils/serde","title":"deserialize_string","content":"pub fn deserialize_string(\n  buf: BitArray,\n) -&gt; Result(#(String, BitArray), String)\n\nSynonyms:\nutils/serde.deserialize_string\nutils/serde deserialize_string","url":"utils/serde.html#deserialize_string"},{"doc":"utils/serde","title":"serialize_bool","content":"pub fn serialize_bool(\n  buf: BytesBuilder,\n  value: Bool,\n) -&gt; BytesBuilder\n\nSynonyms:\nutils/serde.serialize_bool\nutils/serde serialize_bool","url":"utils/serde.html#serialize_bool"},{"doc":"utils/serde","title":"serialize_bytes","content":"pub fn serialize_bytes(\n  buf: BytesBuilder,\n  data: BitArray,\n) -&gt; BytesBuilder\n\nSynonyms:\nutils/serde.serialize_bytes\nutils/serde serialize_bytes","url":"utils/serde.html#serialize_bytes"},{"doc":"utils/serde","title":"serialize_int","content":"pub fn serialize_int(\n  buf: BytesBuilder,\n  num: Int,\n  bit_size: Int,\n) -&gt; BytesBuilder\n\nSynonyms:\nutils/serde.serialize_int\nutils/serde serialize_int","url":"utils/serde.html#serialize_int"},{"doc":"utils/serde","title":"serialize_string","content":"pub fn serialize_string(\n  buf: BytesBuilder,\n  str: String,\n) -&gt; BytesBuilder\n\nSynonyms:\nutils/serde.serialize_string\nutils/serde serialize_string","url":"utils/serde.html#serialize_string"},{"doc":"utils/serde","title":"utils/serde","content":"","url":"utils/serde.html"},{"doc":"merkle/merkle_path","title":"MerklePath","content":"pub type MerklePath {\n  MerklePath(nodes: List(MerklePathNode))\n}\n\nMerklePath(nodes: List(MerklePathNode))\n\n\nSynonyms:\nmerkle/merkle_path.MerklePath\nmerkle/merkle_path MerklePath","url":"merkle/merkle_path.html#MerklePath"},{"doc":"merkle/merkle_path","title":"MerklePathNode","content":"pub type MerklePathNode {\n  MerklePathNode(hash: BitArray, is_left: Bool)\n}\n\nMerklePathNode(hash: BitArray, is_left: Bool)\n\n\nSynonyms:\nmerkle/merkle_path.MerklePathNode\nmerkle/merkle_path MerklePathNode","url":"merkle/merkle_path.html#MerklePathNode"},{"doc":"merkle/merkle_path","title":"deserialize","content":"pub fn deserialize(\n  buf: BitArray,\n) -&gt; Result(#(MerklePath, BitArray), String)\n\nSynonyms:\nmerkle/merkle_path.deserialize\nmerkle/merkle_path deserialize","url":"merkle/merkle_path.html#deserialize"},{"doc":"merkle/merkle_path","title":"deserialize_all","content":"pub fn deserialize_all(\n  buf: BitArray,\n) -&gt; Result(MerklePath, String)\n\nSynonyms:\nmerkle/merkle_path.deserialize_all\nmerkle/merkle_path deserialize_all","url":"merkle/merkle_path.html#deserialize_all"},{"doc":"merkle/merkle_path","title":"empty","content":"pub fn empty() -&gt; MerklePath\n\nSynonyms:\nmerkle/merkle_path.empty\nmerkle/merkle_path empty","url":"merkle/merkle_path.html#empty"},{"doc":"merkle/merkle_path","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  path: MerklePath,\n) -&gt; BytesBuilder\n\nSynonyms:\nmerkle/merkle_path.serialize\nmerkle/merkle_path serialize","url":"merkle/merkle_path.html#serialize"},{"doc":"merkle/merkle_path","title":"serialize_to_bits","content":"pub fn serialize_to_bits(path: MerklePath) -&gt; BitArray\n\nSynonyms:\nmerkle/merkle_path.serialize_to_bits\nmerkle/merkle_path serialize_to_bits","url":"merkle/merkle_path.html#serialize_to_bits"},{"doc":"merkle/merkle_path","title":"merkle/merkle_path","content":"","url":"merkle/merkle_path.html"},{"doc":"transaction/flags","title":"SignatureProofFlags","content":"pub type SignatureProofFlags {\n  WebauthnFieldsFlag\n}\n\nWebauthnFieldsFlag\n\n\nSynonyms:\ntransaction/flags.SignatureProofFlags\ntransaction/flags SignatureProofFlags","url":"transaction/flags.html#SignatureProofFlags"},{"doc":"transaction/flags","title":"TransactionFlags","content":"pub type TransactionFlags {\n  ContractCreationFlag\n  SignalingFlag\n}\n\nContractCreationFlag\n\n\nSignalingFlag\n\n\nSynonyms:\ntransaction/flags.TransactionFlags\ntransaction/flags TransactionFlags","url":"transaction/flags.html#TransactionFlags"},{"doc":"transaction/flags","title":"from_signature_proof_flags","content":"pub fn from_signature_proof_flags(\n  flags: Option(SignatureProofFlags),\n) -&gt; Int\n\nSynonyms:\ntransaction/flags.from_signature_proof_flags\ntransaction/flags from_signature_proof_flags","url":"transaction/flags.html#from_signature_proof_flags"},{"doc":"transaction/flags","title":"from_transaction_flags","content":"pub fn from_transaction_flags(\n  flags: Option(TransactionFlags),\n) -&gt; Int\n\nSynonyms:\ntransaction/flags.from_transaction_flags\ntransaction/flags from_transaction_flags","url":"transaction/flags.html#from_transaction_flags"},{"doc":"transaction/flags","title":"to_signature_proof_flags","content":"pub fn to_signature_proof_flags(\n  flags: Int,\n) -&gt; Result(Option(SignatureProofFlags), String)\n\nSynonyms:\ntransaction/flags.to_signature_proof_flags\ntransaction/flags to_signature_proof_flags","url":"transaction/flags.html#to_signature_proof_flags"},{"doc":"transaction/flags","title":"to_transaction_flags","content":"pub fn to_transaction_flags(\n  flags: Int,\n) -&gt; Result(Option(TransactionFlags), String)\n\nSynonyms:\ntransaction/flags.to_transaction_flags\ntransaction/flags to_transaction_flags","url":"transaction/flags.html#to_transaction_flags"},{"doc":"transaction/flags","title":"transaction/flags","content":"","url":"transaction/flags.html"},{"doc":"transaction/signature_proof","title":"SignatureProof","content":"pub type SignatureProof {\n  SignatureProof(\n    public_key: PublicKey,\n    merkle_path: MerklePath,\n    signature: Signature,\n    webauthn_fields: Option(WebauthnFields),\n  )\n}\n\nSignatureProof(\n  public_key: PublicKey,\n  merkle_path: MerklePath,\n  signature: Signature,\n  webauthn_fields: Option(WebauthnFields),\n)\n\n\nSynonyms:\ntransaction/signature_proof.SignatureProof\ntransaction/signature_proof SignatureProof","url":"transaction/signature_proof.html#SignatureProof"},{"doc":"transaction/signature_proof","title":"WebauthnFields","content":"pub type WebauthnFields {\n  WebauthnFields(\n    origin_json_str: String,\n    has_cross_origin_field: Bool,\n    client_data_extra_json: String,\n    authenticator_data_suffix: BitArray,\n  )\n}\n\nWebauthnFields(\n  origin_json_str: String,\n  has_cross_origin_field: Bool,\n  client_data_extra_json: String,\n  authenticator_data_suffix: BitArray,\n)\n\n\nSynonyms:\ntransaction/signature_proof.WebauthnFields\ntransaction/signature_proof WebauthnFields","url":"transaction/signature_proof.html#WebauthnFields"},{"doc":"transaction/signature_proof","title":"deserialize","content":"pub fn deserialize(\n  buf: BitArray,\n) -&gt; Result(#(SignatureProof, BitArray), String)\n\nSynonyms:\ntransaction/signature_proof.deserialize\ntransaction/signature_proof deserialize","url":"transaction/signature_proof.html#deserialize"},{"doc":"transaction/signature_proof","title":"deserialize_all","content":"pub fn deserialize_all(\n  buf: BitArray,\n) -&gt; Result(SignatureProof, String)\n\nSynonyms:\ntransaction/signature_proof.deserialize_all\ntransaction/signature_proof deserialize_all","url":"transaction/signature_proof.html#deserialize_all"},{"doc":"transaction/signature_proof","title":"deserialize_type_and_flags_byte","content":"pub fn deserialize_type_and_flags_byte(\n  buf: BitArray,\n) -&gt; Result(\n  #(\n    #(SignatureProofAlgorithm, Option(SignatureProofFlags)),\n    BitArray,\n  ),\n  String,\n)\n\nSynonyms:\ntransaction/signature_proof.deserialize_type_and_flags_byte\ntransaction/signature_proof deserialize_type_and_flags_byte","url":"transaction/signature_proof.html#deserialize_type_and_flags_byte"},{"doc":"transaction/signature_proof","title":"deserialize_webauthn_fields","content":"pub fn deserialize_webauthn_fields(\n  buf: BitArray,\n) -&gt; Result(#(WebauthnFields, BitArray), String)\n\nSynonyms:\ntransaction/signature_proof.deserialize_webauthn_fields\ntransaction/signature_proof deserialize_webauthn_fields","url":"transaction/signature_proof.html#deserialize_webauthn_fields"},{"doc":"transaction/signature_proof","title":"make_type_and_flags_byte","content":"pub fn make_type_and_flags_byte(proof: SignatureProof) -&gt; Int\n\nSynonyms:\ntransaction/signature_proof.make_type_and_flags_byte\ntransaction/signature_proof make_type_and_flags_byte","url":"transaction/signature_proof.html#make_type_and_flags_byte"},{"doc":"transaction/signature_proof","title":"parse_type_and_flags_byte","content":"pub fn parse_type_and_flags_byte(\n  byte: Int,\n) -&gt; Result(\n  #(SignatureProofAlgorithm, Option(SignatureProofFlags)),\n  String,\n)\n\nSynonyms:\ntransaction/signature_proof.parse_type_and_flags_byte\ntransaction/signature_proof parse_type_and_flags_byte","url":"transaction/signature_proof.html#parse_type_and_flags_byte"},{"doc":"transaction/signature_proof","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  proof: SignatureProof,\n) -&gt; BytesBuilder\n\nSynonyms:\ntransaction/signature_proof.serialize\ntransaction/signature_proof serialize","url":"transaction/signature_proof.html#serialize"},{"doc":"transaction/signature_proof","title":"serialize_to_bits","content":"pub fn serialize_to_bits(proof: SignatureProof) -&gt; BitArray\n\nSynonyms:\ntransaction/signature_proof.serialize_to_bits\ntransaction/signature_proof serialize_to_bits","url":"transaction/signature_proof.html#serialize_to_bits"},{"doc":"transaction/signature_proof","title":"serialize_webauthn_fields","content":"pub fn serialize_webauthn_fields(\n  builder: BytesBuilder,\n  fields: WebauthnFields,\n) -&gt; BytesBuilder\n\nSynonyms:\ntransaction/signature_proof.serialize_webauthn_fields\ntransaction/signature_proof serialize_webauthn_fields","url":"transaction/signature_proof.html#serialize_webauthn_fields"},{"doc":"transaction/signature_proof","title":"single_sig","content":"pub fn single_sig(\n  public_key: PublicKey,\n  signature: Signature,\n) -&gt; SignatureProof\n\nSynonyms:\ntransaction/signature_proof.single_sig\ntransaction/signature_proof single_sig","url":"transaction/signature_proof.html#single_sig"},{"doc":"transaction/signature_proof","title":"single_sig_webauthn","content":"pub fn single_sig_webauthn(\n  public_key: PublicKey,\n  signature: Signature,\n  webauthn_fields: WebauthnFields,\n) -&gt; SignatureProof\n\nSynonyms:\ntransaction/signature_proof.single_sig_webauthn\ntransaction/signature_proof single_sig_webauthn","url":"transaction/signature_proof.html#single_sig_webauthn"},{"doc":"transaction/signature_proof","title":"transaction/signature_proof","content":"","url":"transaction/signature_proof.html"},{"doc":"transaction/transaction","title":"Transaction","content":"pub type Transaction {\n  Transaction(\n    sender: Address,\n    sender_type: AccountType,\n    sender_data: BitArray,\n    recipient: Address,\n    recipient_type: AccountType,\n    recipient_data: BitArray,\n    value: Coin,\n    fee: Coin,\n    validity_start_height: Int,\n    network_id: NetworkId,\n    flags: Option(TransactionFlags),\n    proof: BitArray,\n  )\n}\n\nTransaction(\n  sender: Address,\n  sender_type: AccountType,\n  sender_data: BitArray,\n  recipient: Address,\n  recipient_type: AccountType,\n  recipient_data: BitArray,\n  value: Coin,\n  fee: Coin,\n  validity_start_height: Int,\n  network_id: NetworkId,\n  flags: Option(TransactionFlags),\n  proof: BitArray,\n)\n\n\nSynonyms:\ntransaction/transaction.Transaction\ntransaction/transaction Transaction","url":"transaction/transaction.html#Transaction"},{"doc":"transaction/transaction","title":"deserialize","content":"pub fn deserialize(\n  buf: BitArray,\n) -&gt; Result(#(Transaction, BitArray), String)\n\nSynonyms:\ntransaction/transaction.deserialize\ntransaction/transaction deserialize","url":"transaction/transaction.html#deserialize"},{"doc":"transaction/transaction","title":"deserialize_all","content":"pub fn deserialize_all(\n  buf: BitArray,\n) -&gt; Result(Transaction, String)\n\nSynonyms:\ntransaction/transaction.deserialize_all\ntransaction/transaction deserialize_all","url":"transaction/transaction.html#deserialize_all"},{"doc":"transaction/transaction","title":"format","content":"pub fn format(tx: Transaction) -&gt; TransactionFormat\n\nSynonyms:\ntransaction/transaction.format\ntransaction/transaction format","url":"transaction/transaction.html#format"},{"doc":"transaction/transaction","title":"from_hex","content":"pub fn from_hex(hex: String) -&gt; Result(Transaction, String)\n\nSynonyms:\ntransaction/transaction.from_hex\ntransaction/transaction from_hex","url":"transaction/transaction.html#from_hex"},{"doc":"transaction/transaction","title":"new_basic","content":"pub fn new_basic(\n  sender: Address,\n  recipient: Address,\n  value: Coin,\n  fee: Coin,\n  validity_start_height: Int,\n  network_id: NetworkId,\n  proof: Option(BitArray),\n) -&gt; Transaction\n\nSynonyms:\ntransaction/transaction.new_basic\ntransaction/transaction new_basic","url":"transaction/transaction.html#new_basic"},{"doc":"transaction/transaction","title":"new_basic_with_data","content":"pub fn new_basic_with_data(\n  sender: Address,\n  recipient: Address,\n  data: BitArray,\n  value: Coin,\n  fee: Coin,\n  validity_start_height: Int,\n  network_id: NetworkId,\n  proof: Option(BitArray),\n) -&gt; Transaction\n\nSynonyms:\ntransaction/transaction.new_basic_with_data\ntransaction/transaction new_basic_with_data","url":"transaction/transaction.html#new_basic_with_data"},{"doc":"transaction/transaction","title":"serialize","content":"pub fn serialize(\n  builder: BytesBuilder,\n  tx: Transaction,\n) -&gt; Result(BytesBuilder, String)\n\nSynonyms:\ntransaction/transaction.serialize\ntransaction/transaction serialize","url":"transaction/transaction.html#serialize"},{"doc":"transaction/transaction","title":"serialize_content","content":"pub fn serialize_content(tx: Transaction) -&gt; BitArray\n\nSynonyms:\ntransaction/transaction.serialize_content\ntransaction/transaction serialize_content","url":"transaction/transaction.html#serialize_content"},{"doc":"transaction/transaction","title":"serialize_to_bits","content":"pub fn serialize_to_bits(\n  tx: Transaction,\n) -&gt; Result(BitArray, String)\n\nSynonyms:\ntransaction/transaction.serialize_to_bits\ntransaction/transaction serialize_to_bits","url":"transaction/transaction.html#serialize_to_bits"},{"doc":"transaction/transaction","title":"set_proof","content":"pub fn set_proof(tx: Transaction, proof: BitArray) -&gt; Transaction\n\nSynonyms:\ntransaction/transaction.set_proof\ntransaction/transaction set_proof","url":"transaction/transaction.html#set_proof"},{"doc":"transaction/transaction","title":"set_signature_proof","content":"pub fn set_signature_proof(\n  tx: Transaction,\n  proof: SignatureProof,\n) -&gt; Transaction\n\nSynonyms:\ntransaction/transaction.set_signature_proof\ntransaction/transaction set_signature_proof","url":"transaction/transaction.html#set_signature_proof"},{"doc":"transaction/transaction","title":"to_hex","content":"pub fn to_hex(tx: Transaction) -&gt; Result(String, String)\n\nSynonyms:\ntransaction/transaction.to_hex\ntransaction/transaction to_hex","url":"transaction/transaction.html#to_hex"},{"doc":"transaction/transaction","title":"transaction/transaction","content":"","url":"transaction/transaction.html"},{"doc":"cli/new_transaction_command","title":"run","content":"pub fn run() -&gt; Command(Nil)\n\nSynonyms:\ncli/new_transaction_command.run\ncli/new_transaction_command run","url":"cli/new_transaction_command.html#run"},{"doc":"cli/new_transaction_command","title":"cli/new_transaction_command","content":"","url":"cli/new_transaction_command.html"},{"doc":"nimiq_gleam","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nnimiq_gleam.main\nnimiq_gleam main","url":"nimiq_gleam.html#main"},{"doc":"nimiq_gleam","title":"nimiq_gleam","content":"","url":"nimiq_gleam.html"}]);